@@ -1255,10 +1255,12 @@ def PlotInteraction(interactions, **kwargs):
       Determine the resolutions (dpi), default = 80.
   ax : fig, optional
       Creates an 'axs' to be added to a figure created outside the role by the user.
+
   Returns
   -------
   out : plot
       The output of the function is the figure with the interactions times with fields.
+      
   See Also
   --------
   For more information and usage examples: https://github.com/pyratlib/pyrat
@@ -1346,3 +1348,45 @@ def PlotInteraction(interactions, **kwargs):
     ax.set_xlabel('Time (s)',fontsize=fontsize)
 
     ax.set_ylim([-barHeight,barHeight])
+
+def Blackrock(data_path, freq): 
+    """
+    Transform a Blackrock file (.ns2) to a pandas DataFrame with all LFP channels.
+
+    Parameters
+    ----------
+    data_path : path
+        Str with data path.
+    freq : int
+        Aquisition frequency.
+
+    Returns
+    -------
+    out : pandas DataFrame
+        The output of the function is the figure with the interactions times with fields.
+        
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+    """
+    from neo.io import BlackrockIO
+    import numpy as np
+    import pandas as pd 
+
+    reader = BlackrockIO(data_path)
+    seg = reader.read_segment()
+
+    column_name = []
+    time = np.arange(0,len(seg.analogsignals[0])/freq,1/freq)
+    values = np.zeros((len(seg.analogsignals[0]),len(seg.analogsignals[0][0])))
+
+    for i in range(len(seg.analogsignals[0][0])):
+        for ç in range(len(seg.analogsignals[0])):
+            values[ç][i] = float(seg.analogsignals[0][ç][i])
+
+    channels = []
+    for i in range(len(seg.analogsignals[0][0])):
+        channels.append('Channel ' + str(i+1))
+
+    df = pd.DataFrame(values,columns=channels,index= None) 
+    df.insert(0, "Time", time, True)
\ No newline at end of file
